from setuptools import setup

setup(
    name='StringAndDate_jasa163',
    version='1.0.0',
    description='Your module description',
    author='jasa163',
    url='https://github.com/hnust-xijing/python-games',
    author_email='jasa163@163.com'
)


